summaryrefslogtreecommitdiffstats
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/libiphone/libiphone.h27
1 files changed, 24 insertions, 3 deletions
diff --git a/include/libiphone/libiphone.h b/include/libiphone/libiphone.h
index 53be73f..0d5257a 100644
--- a/include/libiphone/libiphone.h
+++ b/include/libiphone/libiphone.h
@@ -29,6 +29,7 @@ extern "C" {
#include <stdint.h>
#include <sys/types.h>
#include <sys/stat.h>
+#include <plist/plist.h>
//general errors
#define IPHONE_E_SUCCESS 0
@@ -77,11 +78,23 @@ typedef struct iphone_afc_client_int *iphone_afc_client_t;
struct iphone_afc_file_int;
typedef struct iphone_afc_file_int *iphone_afc_file_t;
+struct iphone_msync_client_int;
+typedef struct iphone_msync_client_int *iphone_msync_client_t;
+
struct iphone_np_client_int;
typedef struct iphone_np_client_int *iphone_np_client_t;
-//device related functions
+//debug related functions
+#define DBGMASK_ALL 0xFFFF
+#define DBGMASK_NONE 0x0000
+#define DBGMASK_USBMUX (1 << 1)
+#define DBGMASK_LOCKDOWND (1 << 2)
+#define DBGMASK_MOBILESYNC (1 << 3)
+
+void iphone_set_debug_mask(uint16_t mask);
void iphone_set_debug(int level);
+
+//device related functions
iphone_error_t iphone_get_device ( iphone_device_t *device );
iphone_error_t iphone_get_specific_device( unsigned int bus_n, int dev_n, iphone_device_t * device );
iphone_error_t iphone_free_device ( iphone_device_t device );
@@ -93,8 +106,8 @@ iphone_error_t iphone_lckd_new_client ( iphone_device_t device, iphone_lckd_clie
iphone_error_t iphone_lckd_free_client( iphone_lckd_client_t client );
iphone_error_t iphone_lckd_start_service ( iphone_lckd_client_t client, const char *service, int *port );
-iphone_error_t iphone_lckd_recv ( iphone_lckd_client_t client, char **dump_data, uint32_t *recv_bytes );
-iphone_error_t iphone_lckd_send ( iphone_lckd_client_t client, char *raw_data, uint32_t length, uint32_t *recv_bytes );
+iphone_error_t iphone_lckd_recv ( iphone_lckd_client_t client, plist_t* plist);
+iphone_error_t iphone_lckd_send ( iphone_lckd_client_t client, plist_t plist);
//usbmux related functions
@@ -126,6 +139,14 @@ iphone_error_t iphone_afc_mkdir ( iphone_afc_client_t client, const char *dir);
iphone_error_t iphone_afc_truncate(iphone_afc_client_t client, const char *path, off_t newsize);
+
+iphone_error_t iphone_msync_new_client(iphone_device_t device, int src_port, int dst_port,
+ iphone_msync_client_t * client);
+iphone_error_t iphone_msync_free_client(iphone_msync_client_t client);
+
+iphone_error_t iphone_msync_recv(iphone_msync_client_t client, plist_t * plist);
+iphone_error_t iphone_msync_send(iphone_msync_client_t client, plist_t plist);
+
#ifdef __cplusplus
}
#endif